#!/bin/sh
#
# $Id: genoccish_gcc53.sh kmohan_blr_backport_28933630_19.8.0.0.200714dbru/3 2020/08/24 06:05:59 kmohan Exp $
#
# genoccish.sh
#
# Copyright (c) 2002, 2020, Oracle and/or its affiliates. 
#
#    NAME
#      genoccish_gcc53.sh - Generate the new occi shared object
#
#    DESCRIPTION
#      Script to generate the occi shared object compatible with g++ 5/6/7/8
#      Assumes that the .a file is already available
#
#      **** PLEASE BACKUP EXISTING libocci_gcc53.so.<ver> ****
#
#    MODIFIED   (MM/DD/YY)
#    kmohan      08/24/20 - Generate new occi shared object
#

ULIB="lib"
LDFLAGS_ARCH=

CUSMK=$ORACLE_HOME/rdbms/lib/env_rdbms.mk
LIBMAJORVSN=`grep '^LIBMAJORVSN *=' $CUSMK | cut -f2 -d=`
LIBMINORVSN=1

#
# library definitions
OLIB=${ORACLE_HOME}/${ULIB}

#
# Library names and locations
OCCI_NAM=occi                                   # (short) library name
OCCI_VER=${LIBMAJORVSN}.${LIBMINORVSN}                  # library version number
OCCI_VERS=${LIBMAJORVSN}
OCCI_LNK=lib${OCCI_NAM}_gcc53.so                      # name of symlink to library
OCCI_LIB=${OCCI_LNK}.${OCCI_VER}                # actual library file name
OCCI_ARC=lib${OCCI_NAM}${OCCI_VERS}_gcc53.a
LIB_DIR=${ORACLE_HOME}/${ULIB}                  # lib. destination directory

# stub libraries for compatibility with higher versions of glibc
STUBS=-L${LIB_DIR}/stubs

if [ ! -z "$SRCHOME" ]
then
        LIB_DIR=${SRCHOME}/rdbms/${ULIB}        # lib. destination directory
fi

GPLUSPLUS="${ORACLE_HOME}/bin/orald"
test -x "${GPLUSPLUS}" || GPLUSPLUS=`/usr/bin/which g++ 2>&1`

LD_MACH_OPT=-m32

# Initialize/override arch specific variables, default for x86.
case `uname -m` in  
"x86_64")          
  LD_MACH_OPT=-m64
  if [ "$PROFILE_ON" = "collect" ]
  then
    INTEL_IPGO="-lipgo"
  else
    INTEL_IPGO=""
  fi
  SYSLIBLIST="-lirc ${INTEL_IPGO} -lsvml"
  ;;
"ia64")  
  if [ "$PROFILE_ON" = "collect" ]
  then
    INTEL_IPGO="-lipgo"
  else
    INTEL_IPGO=""
  fi
  SYSLIBLIST="-lirc ${INTEL_PGO} -lipr"  
  ;;
*)
  if [ "$PROFILE_ON" = "collect" ]
  then
    INTEL_IPGO="-lipgo_pic"
  else
    INTEL_IPGO=""
  fi
  SYSLIBLIST="-lirc_pic ${INTEL_PGO}"
  ;;
esac

# libstdc++ and libm are added so that orald (and gcc) can be used for linking
SYSLIBLIST="${SYSLIBLIST} -lstdc++ -lm"

[ ! -f "${GPLUSPLUS}" ] && echo "libocci.so.$OCCI_VER not regenerated. g++ not found" && exit;

#
# Linker command and options

if [ -z ${LDOBJSZ} ]
then
    if [ -z ${LDFLAGS_ARCH} ]
    then
        LDOBJSZ=${LD_MACH_OPT}
    fi
fi

LD="${GPLUSPLUS} -Wl,-soname=${OCCI_LIB} ${LDOBJSZ} ${LDFLAGS_ARCH} ${STUBS} \
    -o ${LIB_DIR}/${OCCI_LIB} -shared \
    -Wl,--whole-archive ${LIB_DIR}/${OCCI_ARC} -L${OLIB} -Wl,--no-whole-archive ${SYSLIBLIST}"

# Create library
/bin/rm -f ${LIB_DIR}/${OCCI_LIB}
${LD}

exit 0
